==> zio-aws-route53recoverycontrolconfig_2.12-5.17.126.1-sources.jar: zio/aws/route53recoverycontrolconfig/model/DescribeControlPanelRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeControlPanelRequest(controlPanelArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeControlPanelRequest = {
    import DescribeControlPanelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeControlPanelRequest
      .builder()
      .controlPanelArn(__string.unwrap(controlPanelArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DescribeControlPanelRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DescribeControlPanelRequest
      .wrap(buildAwsValue())
}
object DescribeControlPanelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeControlPanelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DescribeControlPanelRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DescribeControlPanelRequest(controlPanelArn)
    def controlPanelArn: __string
    def getControlPanelArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(controlPanelArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeControlPanelRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DescribeControlPanelRequest.ReadOnly {
    override val controlPanelArn: __string =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__string(impl.controlPanelArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeControlPanelRequest
  ): zio.aws.route53recoverycontrolconfig.model.DescribeControlPanelRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_2.13-5.17.153.3-sources.jar: zio/aws/route53recoverycontrolconfig/model/DescribeControlPanelRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeControlPanelRequest(controlPanelArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeControlPanelRequest = {
    import DescribeControlPanelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeControlPanelRequest
      .builder()
      .controlPanelArn(controlPanelArn: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DescribeControlPanelRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DescribeControlPanelRequest
      .wrap(buildAwsValue())
}
object DescribeControlPanelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeControlPanelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DescribeControlPanelRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DescribeControlPanelRequest(controlPanelArn)
    def controlPanelArn: __string
    def getControlPanelArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(controlPanelArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeControlPanelRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DescribeControlPanelRequest.ReadOnly {
    override val controlPanelArn: __string = impl.controlPanelArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeControlPanelRequest
  ): zio.aws.route53recoverycontrolconfig.model.DescribeControlPanelRequest.ReadOnly =
    new Wrapper(impl)
}
